@@ -5,7 +5,7 @@
 # http://www.apache.org/licenses/LICENSE-2.0
 #
 # Authors:
-# - Paul Nilsson, paul.nilsson@cern.ch, 2018-2021
+# - Paul Nilsson, paul.nilsson@cern.ch, 2018-2022
 
 # This module contains implementations of job monitoring tasks
 
@@ -15,6 +15,7 @@ from subprocess import PIPE
 from glob import glob
 
 from pilot.common.errorcodes import ErrorCodes
+from pilot.common.exception import PilotException
 from pilot.util.auxiliary import set_pilot_state, show_memory_usage
 from pilot.util.config import config
 from pilot.util.container import execute
@@ -23,6 +24,7 @@ from pilot.util.loopingjob import looping_job
 from pilot.util.math import convert_mb_to_b, human2bytes
 from pilot.util.parameters import convert_to_int, get_maximum_input_sizes
 from pilot.util.processes import get_current_cpu_consumption_time, kill_processes, get_number_of_child_processes
+from pilot.util.timing import get_time_since_start
 from pilot.util.workernode import get_local_disk_space, check_hz
 
 import logging
@@ -92,7 +94,7 @@ def job_monitor_tasks(job, mt, args):
             return exit_code, diagnostics
 
     # is it time to check for looping jobs?
-    exit_code, diagnostics = verify_looping_job(current_time, mt, job)
+    exit_code, diagnostics = verify_looping_job(current_time, mt, job, args)
     if exit_code != 0:
         return exit_code, diagnostics
 
@@ -271,22 +273,32 @@ def verify_user_proxy(current_time, mt):
     return 0, ""
 
 
-def verify_looping_job(current_time, mt, job):
+def verify_looping_job(current_time, mt, job, args):
     """
     Verify that the job is not looping.
 
     :param current_time: current time at the start of the monitoring loop (int).
     :param mt: measured time object.
     :param job: job object.
+    :param args: pilot args object.
     :return: exit code (int), error diagnostics (string).
     """
 
-    # only perform looping job check if desired
-    if not job.looping_check:
+    # only perform looping job check if desired and enough time has passed since start
+    pilot_user = os.environ.get('PILOT_USER', 'generic').lower()
+    loopingjob_definitions = __import__('pilot.user.%s.loopingjob_definitions' % pilot_user, globals(), locals(), [pilot_user], 0)
+    runcheck = loopingjob_definitions.allow_loopingjob_detection()
+    if not job.looping_check and runcheck:
         logger.debug('looping check not desired')
         return 0, ""
 
+    time_since_start = int(get_time_since_start(args))
     looping_verification_time = convert_to_int(config.Pilot.looping_verification_time, default=600)
+    if time_since_start < looping_verification_time:
+        logger.debug(f'no point in running looping job algorithm since time_since_start={time_since_start} s < '
+                     f'looping_verification_time={looping_verification_time} s')
+        return 0, ""
+
     if current_time - mt.get('ct_looping') > looping_verification_time:
         # is the job looping?
         try:
@@ -543,15 +555,26 @@ def check_local_space(initial=True):
     # is there enough local space to run a job?
     cwd = os.getcwd()
     logger.debug(f'checking local space on {cwd}')
-    spaceleft = convert_mb_to_b(get_local_disk_space(cwd))  # B (diskspace is in MB)
-    free_space_limit = human2bytes(config.Pilot.free_space_limit) if initial else human2bytes(config.Pilot.free_space_limit_running)
+    try:
+        local_space = get_local_disk_space(cwd)
+    except PilotException as exc:
+        diagnostics = exc.get_detail()
+        logger.warning(f'exception caught while executing df: {diagnostics} (ignoring)')
+        return ec, diagnostics
 
-    if spaceleft <= free_space_limit:
-        diagnostics = f'too little space left on local disk to run job: {spaceleft} B (need > {free_space_limit} B)'
-        ec = errors.NOLOCALSPACE
-        logger.warning(diagnostics)
+    if local_space:
+        spaceleft = convert_mb_to_b(local_space)  # B (diskspace is in MB)
+        free_space_limit = human2bytes(config.Pilot.free_space_limit) if initial else human2bytes(config.Pilot.free_space_limit_running)
+
+        if spaceleft <= free_space_limit:
+            diagnostics = f'too little space left on local disk to run job: {spaceleft} B (need > {free_space_limit} B)'
+            ec = errors.NOLOCALSPACE
+            logger.warning(diagnostics)
+        else:
+            logger.info(f'sufficient remaining disk space ({spaceleft} B)')
     else:
-        logger.info(f'sufficient remaining disk space ({spaceleft} B)')
+        diagnostics = 'get_local_disk_space() returned None'
+        logger.warning(diagnostics)
 
     return ec, diagnostics
 
@@ -631,7 +654,7 @@ def get_max_allowed_work_dir_size():
         # grace margin, as discussed in https://its.cern.ch/jira/browse/ATLASPANDA-482
         margin = 10.0  # percent, read later from somewhere
         maxwdirsize = int(maxwdirsize * (1 + margin / 100.0))
-        logger.info(f"work directory size check will use {maxwdirsize} B as a max limit (10%% grace limit added)")
+        logger.info(f"work directory size check will use {maxwdirsize} B as a max limit (10% grace limit added)")
 
     return maxwdirsize
 
@@ -692,6 +715,10 @@ def check_output_file_sizes(job):
             max_fsize = human2bytes(config.Pilot.maximum_output_file_size)
             if fsize and fsize < max_fsize:
                 logger.info(f'output file {path} is within allowed size limit ({fsize} B < {max_fsize} B)')
+            elif fsize == 0:
+                exit_code = errors.EMPTYOUTPUTFILE
+                diagnostics = f'zero size output file detected: {path}'
+                logger.warning(diagnostics)
             else:
                 exit_code = errors.OUTPUTFILETOOLARGE
                 diagnostics = f'output file {path} is not within allowed size limit ({fsize} B > {max_fsize} B)'
